==> pyreaqtive-1.0.0.tar.gz: pyreaqtive-1.0.0/pyreaqtive/widgets/rqspinbox.py <==
from PyQt5.QtWidgets import QSpinBox
from PyQt5.QtCore import pyqtSlot

from ..models import RQInt, RQBool, RQObject
from .rqwidget import RQWidget
from typing import Union


class RQSpinBox(RQWidget, QSpinBox):
    """Reactive SpinBox Widget"""

    model: Union[RQInt, RQObject] = None
    """Model linked to the widget"""

    def __init__(self, model: Union[RQInt, int, RQObject], *args, rq_if: Union[RQBool, None] = None, **kwargs):
        """Constructor.

        Args:
            model: Model to link the widget to

            args: arguments to pass to the native pyqt widget

            rq_if: RQBool that controls the visibility

            **kwargs: arguments to pass to the native pyqt widget
        """
        if model.rq_read_only:
            raise IOError("Cannot connect rqspinbox to a read only model")

        RQWidget.__init__(self, model, rq_if)
        QSpinBox.__init__(self, *args, **kwargs)

        self._rq_data_changed()
        self.model.rq_data_changed.connect(self._rq_data_changed)
        self.valueChanged.connect(self._value_changed)

    @pyqtSlot()
    def _rq_data_changed(self) -> None:
        """Slot triggered when the model changes value.

        Updates value of the spinbox
        """
        if not self._rq_writing:
            self._rq_reading = True
            self.setValue(int(self.model))
            self._rq_reading = False

    _rq_writing = False
    """Flag to signal that this widget is triggering the update and is writing to the model"""

    _rq_reading = False
    """Flag to indicate that the model changed and the widget is reading the model"""

    @pyqtSlot()
    def _value_changed(self) -> None:
        """Slot triggered when the user changes value of the spinbox.

        Propagates changes to the model
        """
        if not self._rq_reading:
            self._rq_writing = True
            self.model.set(self.value())
            self._rq_writing = False

==> pyreaqtive-1.1.1.tar.gz: pyreaqtive-1.1.1/pyreaqtive/widgets/rqspinbox.py <==
from typing import Union

from PyQt5.QtCore import pyqtSlot
from PyQt5.QtWidgets import QSpinBox

from .rqwidget import RQWidget
from ..models import RQInt, RQBool, RQObject, RQModel


class RQSpinBox(RQWidget, QSpinBox):
    """Reactive SpinBox Widget"""

    model: Union[RQInt, RQObject]
    """Model linked to the widget"""

    def __init__(self,
                 model: Union[RQInt, int, RQObject],
                 *args,
                 rq_if: Union[RQBool, None] = None,
                 rq_disabled: Union[RQBool, None] = None,
                 **kwargs):
        """Constructor.

        Args:
            model: Model to link the widget to
            *args: arguments to pass to the native pyqt widget
            rq_if: RQBool that controls the visibility
            rq_disabled: RQBool that controls the disabling
            **kwargs: arguments to pass to the native pyqt widget
        """
        if isinstance(type(model), RQModel):
            if model.rq_read_only:  # type: ignore
                raise IOError("Cannot connect rqspinbox to a read only model")

        RQWidget.__init__(self, model, rq_if, rq_disabled)
        QSpinBox.__init__(self, *args, **kwargs)
        self.rq_init_widget()

        self._rq_data_changed()
        self.model.rq_data_changed.connect(self._rq_data_changed)
        self.valueChanged.connect(self._value_changed)

    @pyqtSlot()
    def _rq_data_changed(self) -> None:
        """Slot triggered when the model changes value.

        Updates value of the spinbox
        """
        if not self._rq_writing:
            self._rq_reading = True
            self.setValue(int(self.model))
            self._rq_reading = False

    _rq_writing = False
    """Flag to signal that this widget is triggering the update and is writing to the model"""

    _rq_reading = False
    """Flag to indicate that the model changed and the widget is reading the model"""

    @pyqtSlot()
    def _value_changed(self) -> None:
        """Slot triggered when the user changes value of the spinbox.

        Propagates changes to the model
        """
        if not self._rq_reading:
            self._rq_writing = True
            self.model.set(self.value())
            self._rq_writing = False
